Opacities (''taurex.opacity'')
===============================

Base
-----------------------------

.. automodule:: taurex.opacity.opacity
   :members:
   :undoc-members:
   :show-inheritance:

Base Interpolator
----------------------------------------

.. automodule:: taurex.opacity.interpolateopacity
   :members:
   :undoc-members:
   :show-inheritance:

Pickle Format (``.pickle``)
-----------------------------------

.. automodule:: taurex.opacity.pickleopacity
   :members:
   :undoc-members:
   :show-inheritance:

HDF5 Format (``.hdf5``)
-----------------------------------

.. automodule:: taurex.opacity.hdf5opacity
   :members:
   :undoc-members:
   :show-inheritance:

ExoTransmit Format (``.dat``)
-----------------------------------

.. automodule:: taurex.opacity.exotransmit
   :members:
   :undoc-members:
   :show-inheritance: